Class: Aws::KafkaConnect::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::KafkaConnect::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-kafkaconnect/client.rb,
sig/client.rbs
Overview
An API client for KafkaConnect. To construct a client, you need to configure a :region and :credentials.
client = Aws::KafkaConnect::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateConnectorResponseSuccess, _CreateCustomPluginResponseSuccess, _CreateWorkerConfigurationResponseSuccess, _DeleteConnectorResponseSuccess, _DeleteCustomPluginResponseSuccess, _DeleteWorkerConfigurationResponseSuccess, _DescribeConnectorOperationResponseSuccess, _DescribeConnectorResponseSuccess, _DescribeCustomPluginResponseSuccess, _DescribeWorkerConfigurationResponseSuccess, _ListConnectorOperationsResponseSuccess, _ListConnectorsResponseSuccess, _ListCustomPluginsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListWorkerConfigurationsResponseSuccess, _RestartConnectorResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateConnectorResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates a connector using the specified properties.
-
#create_custom_plugin(params = {}) ⇒ Types::CreateCustomPluginResponse
Creates a custom plugin using the specified properties.
-
#create_worker_configuration(params = {}) ⇒ Types::CreateWorkerConfigurationResponse
Creates a worker configuration using the specified properties.
-
#delete_connector(params = {}) ⇒ Types::DeleteConnectorResponse
Deletes the specified connector.
-
#delete_custom_plugin(params = {}) ⇒ Types::DeleteCustomPluginResponse
Deletes a custom plugin.
-
#delete_worker_configuration(params = {}) ⇒ Types::DeleteWorkerConfigurationResponse
Deletes the specified worker configuration.
-
#describe_connector(params = {}) ⇒ Types::DescribeConnectorResponse
Returns summary information about the connector.
-
#describe_connector_operation(params = {}) ⇒ Types::DescribeConnectorOperationResponse
Returns information about the specified connector's operations.
-
#describe_custom_plugin(params = {}) ⇒ Types::DescribeCustomPluginResponse
A summary description of the custom plugin.
-
#describe_worker_configuration(params = {}) ⇒ Types::DescribeWorkerConfigurationResponse
Returns information about a worker configuration.
-
#list_connector_operations(params = {}) ⇒ Types::ListConnectorOperationsResponse
Lists information about a connector's operation(s).
-
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Returns a list of all the connectors in this account and Region.
-
#list_custom_plugins(params = {}) ⇒ Types::ListCustomPluginsResponse
Returns a list of all of the custom plugins in this account and Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags attached to the specified resource.
-
#list_worker_configurations(params = {}) ⇒ Types::ListWorkerConfigurationsResponse
Returns a list of all of the worker configurations in this account and Region.
-
#restart_connector(params = {}) ⇒ Types::RestartConnectorResponse
Restarts the specified connector.
-
#tag_resource(params = {}) ⇒ Struct
Attaches tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_connector(params = {}) ⇒ Types::UpdateConnectorResponse
Updates the specified connector.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1551 1552 1553 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1551 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1554 1555 1556 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1554 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1524 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::KafkaConnect') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-kafkaconnect' context[:gem_version] = '1.61.0' Seahorse::Client::Request.new(handlers, context) end |
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates a connector using the specified properties.
88 |
# File 'sig/client.rbs', line 88
def create_connector: (
|
#create_custom_plugin(params = {}) ⇒ Types::CreateCustomPluginResponse
Creates a custom plugin using the specified properties.
169 |
# File 'sig/client.rbs', line 169
def create_custom_plugin: (
|
#create_worker_configuration(params = {}) ⇒ Types::CreateWorkerConfigurationResponse
Creates a worker configuration using the specified properties.
193 |
# File 'sig/client.rbs', line 193
def create_worker_configuration: (
|
#delete_connector(params = {}) ⇒ Types::DeleteConnectorResponse
Deletes the specified connector.
207 |
# File 'sig/client.rbs', line 207
def delete_connector: (
|
#delete_custom_plugin(params = {}) ⇒ Types::DeleteCustomPluginResponse
Deletes a custom plugin.
219 |
# File 'sig/client.rbs', line 219
def delete_custom_plugin: (
|
#delete_worker_configuration(params = {}) ⇒ Types::DeleteWorkerConfigurationResponse
Deletes the specified worker configuration.
230 |
# File 'sig/client.rbs', line 230
def delete_worker_configuration: (
|
#describe_connector(params = {}) ⇒ Types::DescribeConnectorResponse
Returns summary information about the connector.
257 |
# File 'sig/client.rbs', line 257
def describe_connector: (
|
#describe_connector_operation(params = {}) ⇒ Types::DescribeConnectorOperationResponse
Returns information about the specified connector's operations.
278 |
# File 'sig/client.rbs', line 278
def describe_connector_operation: (
|
#describe_custom_plugin(params = {}) ⇒ Types::DescribeCustomPluginResponse
A summary description of the custom plugin.
294 |
# File 'sig/client.rbs', line 294
def describe_custom_plugin: (
|
#describe_worker_configuration(params = {}) ⇒ Types::DescribeWorkerConfigurationResponse
Returns information about a worker configuration.
309 |
# File 'sig/client.rbs', line 309
def describe_worker_configuration: (
|
#list_connector_operations(params = {}) ⇒ Types::ListConnectorOperationsResponse
Lists information about a connector's operation(s).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
320 |
# File 'sig/client.rbs', line 320
def list_connector_operations: (
|
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Returns a list of all the connectors in this account and Region. The list is limited to connectors whose name starts with the specified prefix. The response also includes a description of each of the listed connectors.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
333 |
# File 'sig/client.rbs', line 333
def list_connectors: (
|
#list_custom_plugins(params = {}) ⇒ Types::ListCustomPluginsResponse
Returns a list of all of the custom plugins in this account and Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
346 |
# File 'sig/client.rbs', line 346
def list_custom_plugins: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags attached to the specified resource.
358 |
# File 'sig/client.rbs', line 358
def list_tags_for_resource: (
|
#list_worker_configurations(params = {}) ⇒ Types::ListWorkerConfigurationsResponse
Returns a list of all of the worker configurations in this account and Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
369 |
# File 'sig/client.rbs', line 369
def list_worker_configurations: (
|
#restart_connector(params = {}) ⇒ Types::RestartConnectorResponse
Restarts the specified connector. By default, this operation restarts
the connector and all of its tasks. This operation is asynchronous and
returns a connector operation ARN that you can pass to
DescribeConnectorOperation to track the state of the restart.
382 |
# File 'sig/client.rbs', line 382
def restart_connector: (
|
#tag_resource(params = {}) ⇒ Struct
Attaches tags to the specified resource.
392 |
# File 'sig/client.rbs', line 392
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
402 |
# File 'sig/client.rbs', line 402
def untag_resource: (
|
#update_connector(params = {}) ⇒ Types::UpdateConnectorResponse
Updates the specified connector. For request body, specify only one
parameter: either capacity or connectorConfiguration.
415 |
# File 'sig/client.rbs', line 415
def update_connector: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1544 1545 1546 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1544 def waiter_names [] end |