Class: Aws::KafkaConnect::Types::ConnectorSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafkaconnect/types.rb

Overview

Summary of a connector.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacityTypes::CapacityDescription

The connector’s compute capacity settings.



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#connector_arnString

The Amazon Resource Name (ARN) of the connector.

Returns:

  • (String)


434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#connector_descriptionString

The description of the connector.

Returns:

  • (String)


434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#connector_nameString

The name of the connector.

Returns:

  • (String)


434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#connector_stateString

The state of the connector.

Returns:

  • (String)


434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The time that the connector was created.

Returns:

  • (Time)


434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#current_versionString

The current version of the connector.

Returns:

  • (String)


434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#kafka_clusterTypes::KafkaClusterDescription

The details of the Apache Kafka cluster to which the connector is connected.



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#kafka_cluster_client_authenticationTypes::KafkaClusterClientAuthenticationDescription

The type of client authentication used to connect to the Apache Kafka cluster. The value is NONE when no client authentication is used.



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#kafka_cluster_encryption_in_transitTypes::KafkaClusterEncryptionInTransitDescription

Details of encryption in transit to the Apache Kafka cluster.



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#kafka_connect_versionString

The version of Kafka Connect. It has to be compatible with both the Apache Kafka cluster’s version and the plugins.

Returns:

  • (String)


434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#log_deliveryTypes::LogDeliveryDescription

The settings for delivering connector logs to Amazon CloudWatch Logs.



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#network_typeString

The network type of the connector. It gives connectors connectivity to either IPv4 (IPV4) or IPv4 and IPv6 (DUAL) destinations. Defaults to IPV4.

Returns:

  • (String)


434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#pluginsArray<Types::PluginDescription>

Specifies which plugins were used for this connector.

Returns:



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#service_execution_role_arnString

The Amazon Resource Name (ARN) of the IAM role used by the connector to access Amazon Web Services resources.

Returns:

  • (String)


434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#worker_configurationTypes::WorkerConfigurationDescription

The worker configurations that are in use with the connector.



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 434

class ConnectorSummary < Struct.new(
  :capacity,
  :connector_arn,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration)
  SENSITIVE = []
  include Aws::Structure
end