Class: Aws::KafkaConnect::Types::CreateConnectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::KafkaConnect::Types::CreateConnectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafkaconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:connector_configuration]
Instance Attribute Summary collapse
-
#capacity ⇒ Types::Capacity
Information about the capacity allocated to the connector.
-
#connector_configuration ⇒ Hash<String,String>
A map of keys to values that represent the configuration for the connector.
-
#connector_description ⇒ String
A summary description of the connector.
-
#connector_name ⇒ String
The name of the connector.
-
#kafka_cluster ⇒ Types::KafkaCluster
Specifies which Apache Kafka cluster to connect to.
-
#kafka_cluster_client_authentication ⇒ Types::KafkaClusterClientAuthentication
Details of the client authentication used by the Apache Kafka cluster.
-
#kafka_cluster_encryption_in_transit ⇒ Types::KafkaClusterEncryptionInTransit
Details of encryption in transit to the Apache Kafka cluster.
-
#kafka_connect_version ⇒ String
The version of Kafka Connect.
-
#log_delivery ⇒ Types::LogDelivery
Details about log delivery.
-
#network_type ⇒ String
The network type of the connector.
-
#plugins ⇒ Array<Types::Plugin>
Amazon MSK Connect does not currently support specifying multiple plugins as a list.
-
#service_execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used by the connector to access the Amazon Web Services resources that it needs.
-
#tags ⇒ Hash<String,String>
The tags you want to attach to the connector.
-
#worker_configuration ⇒ Types::WorkerConfiguration
Specifies which worker configuration to use with the connector.
Instance Attribute Details
#capacity ⇒ Types::Capacity
Information about the capacity allocated to the connector. Exactly one of the two properties must be specified.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 529 class CreateConnectorRequest < Struct.new( :capacity, :connector_configuration, :connector_description, :connector_name, :kafka_cluster, :kafka_cluster_client_authentication, :kafka_cluster_encryption_in_transit, :kafka_connect_version, :log_delivery, :network_type, :plugins, :service_execution_role_arn, :worker_configuration, :tags) SENSITIVE = [:connector_configuration] include Aws::Structure end |
#connector_configuration ⇒ Hash<String,String>
A map of keys to values that represent the configuration for the connector.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 529 class CreateConnectorRequest < Struct.new( :capacity, :connector_configuration, :connector_description, :connector_name, :kafka_cluster, :kafka_cluster_client_authentication, :kafka_cluster_encryption_in_transit, :kafka_connect_version, :log_delivery, :network_type, :plugins, :service_execution_role_arn, :worker_configuration, :tags) SENSITIVE = [:connector_configuration] include Aws::Structure end |
#connector_description ⇒ String
A summary description of the connector.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 529 class CreateConnectorRequest < Struct.new( :capacity, :connector_configuration, :connector_description, :connector_name, :kafka_cluster, :kafka_cluster_client_authentication, :kafka_cluster_encryption_in_transit, :kafka_connect_version, :log_delivery, :network_type, :plugins, :service_execution_role_arn, :worker_configuration, :tags) SENSITIVE = [:connector_configuration] include Aws::Structure end |
#connector_name ⇒ String
The name of the connector.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 529 class CreateConnectorRequest < Struct.new( :capacity, :connector_configuration, :connector_description, :connector_name, :kafka_cluster, :kafka_cluster_client_authentication, :kafka_cluster_encryption_in_transit, :kafka_connect_version, :log_delivery, :network_type, :plugins, :service_execution_role_arn, :worker_configuration, :tags) SENSITIVE = [:connector_configuration] include Aws::Structure end |
#kafka_cluster ⇒ Types::KafkaCluster
Specifies which Apache Kafka cluster to connect to.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 529 class CreateConnectorRequest < Struct.new( :capacity, :connector_configuration, :connector_description, :connector_name, :kafka_cluster, :kafka_cluster_client_authentication, :kafka_cluster_encryption_in_transit, :kafka_connect_version, :log_delivery, :network_type, :plugins, :service_execution_role_arn, :worker_configuration, :tags) SENSITIVE = [:connector_configuration] include Aws::Structure end |
#kafka_cluster_client_authentication ⇒ Types::KafkaClusterClientAuthentication
Details of the client authentication used by the Apache Kafka cluster.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 529 class CreateConnectorRequest < Struct.new( :capacity, :connector_configuration, :connector_description, :connector_name, :kafka_cluster, :kafka_cluster_client_authentication, :kafka_cluster_encryption_in_transit, :kafka_connect_version, :log_delivery, :network_type, :plugins, :service_execution_role_arn, :worker_configuration, :tags) SENSITIVE = [:connector_configuration] include Aws::Structure end |
#kafka_cluster_encryption_in_transit ⇒ Types::KafkaClusterEncryptionInTransit
Details of encryption in transit to the Apache Kafka cluster.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 529 class CreateConnectorRequest < Struct.new( :capacity, :connector_configuration, :connector_description, :connector_name, :kafka_cluster, :kafka_cluster_client_authentication, :kafka_cluster_encryption_in_transit, :kafka_connect_version, :log_delivery, :network_type, :plugins, :service_execution_role_arn, :worker_configuration, :tags) SENSITIVE = [:connector_configuration] include Aws::Structure end |
#kafka_connect_version ⇒ String
The version of Kafka Connect. It has to be compatible with both the Apache Kafka cluster’s version and the plugins.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 529 class CreateConnectorRequest < Struct.new( :capacity, :connector_configuration, :connector_description, :connector_name, :kafka_cluster, :kafka_cluster_client_authentication, :kafka_cluster_encryption_in_transit, :kafka_connect_version, :log_delivery, :network_type, :plugins, :service_execution_role_arn, :worker_configuration, :tags) SENSITIVE = [:connector_configuration] include Aws::Structure end |
#log_delivery ⇒ Types::LogDelivery
Details about log delivery.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 529 class CreateConnectorRequest < Struct.new( :capacity, :connector_configuration, :connector_description, :connector_name, :kafka_cluster, :kafka_cluster_client_authentication, :kafka_cluster_encryption_in_transit, :kafka_connect_version, :log_delivery, :network_type, :plugins, :service_execution_role_arn, :worker_configuration, :tags) SENSITIVE = [:connector_configuration] include Aws::Structure end |
#network_type ⇒ String
The network type of the connector. It gives connectors connectivity to either IPv4 (IPV4) or IPv4 and IPv6 (DUAL) destinations. Defaults to IPV4.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 529 class CreateConnectorRequest < Struct.new( :capacity, :connector_configuration, :connector_description, :connector_name, :kafka_cluster, :kafka_cluster_client_authentication, :kafka_cluster_encryption_in_transit, :kafka_connect_version, :log_delivery, :network_type, :plugins, :service_execution_role_arn, :worker_configuration, :tags) SENSITIVE = [:connector_configuration] include Aws::Structure end |
#plugins ⇒ Array<Types::Plugin>
Amazon MSK Connect does not currently support specifying multiple plugins as a list. To use more than one plugin for your connector, you can create a single custom plugin using a ZIP file that bundles multiple plugins together.
Specifies which plugin to use for the connector. You must specify a
single-element list containing one customPlugin object.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 529 class CreateConnectorRequest < Struct.new( :capacity, :connector_configuration, :connector_description, :connector_name, :kafka_cluster, :kafka_cluster_client_authentication, :kafka_cluster_encryption_in_transit, :kafka_connect_version, :log_delivery, :network_type, :plugins, :service_execution_role_arn, :worker_configuration, :tags) SENSITIVE = [:connector_configuration] include Aws::Structure end |
#service_execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used by the connector to access the Amazon Web Services resources that it needs. The types of resources depends on the logic of the connector. For example, a connector that has Amazon S3 as a destination must have permissions that allow it to write to the S3 destination bucket.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 529 class CreateConnectorRequest < Struct.new( :capacity, :connector_configuration, :connector_description, :connector_name, :kafka_cluster, :kafka_cluster_client_authentication, :kafka_cluster_encryption_in_transit, :kafka_connect_version, :log_delivery, :network_type, :plugins, :service_execution_role_arn, :worker_configuration, :tags) SENSITIVE = [:connector_configuration] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags you want to attach to the connector.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 529 class CreateConnectorRequest < Struct.new( :capacity, :connector_configuration, :connector_description, :connector_name, :kafka_cluster, :kafka_cluster_client_authentication, :kafka_cluster_encryption_in_transit, :kafka_connect_version, :log_delivery, :network_type, :plugins, :service_execution_role_arn, :worker_configuration, :tags) SENSITIVE = [:connector_configuration] include Aws::Structure end |
#worker_configuration ⇒ Types::WorkerConfiguration
Specifies which worker configuration to use with the connector.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 529 class CreateConnectorRequest < Struct.new( :capacity, :connector_configuration, :connector_description, :connector_name, :kafka_cluster, :kafka_cluster_client_authentication, :kafka_cluster_encryption_in_transit, :kafka_connect_version, :log_delivery, :network_type, :plugins, :service_execution_role_arn, :worker_configuration, :tags) SENSITIVE = [:connector_configuration] include Aws::Structure end |