Class: Aws::KafkaConnect::Types::DescribeConnectorResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafkaconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:connector_configuration]

Instance Attribute Summary collapse

Instance Attribute Details

#capacityTypes::CapacityDescription

Information about the capacity of the connector, whether it is auto scaled or provisioned.



1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#connector_arnString

The Amazon Resource Name (ARN) of the connector.

Returns:

  • (String)


1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#connector_configurationHash<String,String>

A map of keys to values that represent the configuration for the connector.

Returns:

  • (Hash<String,String>)


1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#connector_descriptionString

A summary description of the connector.

Returns:

  • (String)


1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#connector_nameString

The name of the connector.

Returns:

  • (String)


1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#connector_stateString

The state of the connector.

Returns:

  • (String)


1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#creation_timeTime

The time the connector was created.

Returns:

  • (Time)


1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#current_versionString

The current version of the connector.

Returns:

  • (String)


1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#kafka_clusterTypes::KafkaClusterDescription

The Apache Kafka cluster that the connector is connected to.



1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#kafka_cluster_client_authenticationTypes::KafkaClusterClientAuthenticationDescription

The type of client authentication used to connect to the Apache Kafka cluster. The value is NONE when no client authentication is used.



1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#kafka_cluster_encryption_in_transitTypes::KafkaClusterEncryptionInTransitDescription

Details of encryption in transit to the Apache Kafka cluster.



1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#kafka_connect_versionString

The version of Kafka Connect. It has to be compatible with both the Apache Kafka cluster’s version and the plugins.

Returns:

  • (String)


1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#log_deliveryTypes::LogDeliveryDescription

Details about delivering logs to Amazon CloudWatch Logs.



1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#network_typeString

The network type of the connector. It gives connectors connectivity to either IPv4 (IPV4) or IPv4 and IPv6 (DUAL) destinations. Defaults to IPV4.

Returns:

  • (String)


1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#pluginsArray<Types::PluginDescription>

Specifies which plugins were used for this connector.

Returns:



1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#service_execution_role_arnString

The Amazon Resource Name (ARN) of the IAM role used by the connector to access Amazon Web Services resources.

Returns:

  • (String)


1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#state_descriptionTypes::StateDescription

Details about the state of a connector.



1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end

#worker_configurationTypes::WorkerConfigurationDescription

Specifies which worker configuration was used for the connector.



1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1131

class DescribeConnectorResponse < Struct.new(
  :capacity,
  :connector_arn,
  :connector_configuration,
  :connector_description,
  :connector_name,
  :connector_state,
  :creation_time,
  :current_version,
  :kafka_cluster,
  :kafka_cluster_client_authentication,
  :kafka_cluster_encryption_in_transit,
  :kafka_connect_version,
  :log_delivery,
  :network_type,
  :plugins,
  :service_execution_role_arn,
  :worker_configuration,
  :state_description)
  SENSITIVE = [:connector_configuration]
  include Aws::Structure
end