Class: Aws::KafkaConnect::Types::RestartConnectorRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kafkaconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connector_arnString

The Amazon Resource Name (ARN) of the connector that you want to restart.

Returns:

  • (String)


1776
1777
1778
1779
1780
1781
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1776

class RestartConnectorRequest < Struct.new(
  :connector_arn,
  :only_failed_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#only_failed_tasksBoolean

Specifies whether to restart only the connector's failed tasks. If true, the operation restarts only the tasks that are currently in a failed state, and healthy tasks continue running. If false or not specified, the operation restarts the connector and all of its tasks.

Returns:

  • (Boolean)


1776
1777
1778
1779
1780
1781
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1776

class RestartConnectorRequest < Struct.new(
  :connector_arn,
  :only_failed_tasks)
  SENSITIVE = []
  include Aws::Structure
end