Class: Aws::KafkaConnect::Types::RestartConnectorResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::KafkaConnect::Types::RestartConnectorResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafkaconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connector_arn ⇒ String
The Amazon Resource Name (ARN) of the connector.
-
#connector_operation_arn ⇒ String
The Amazon Resource Name (ARN) of the connector operation created to perform the restart.
Instance Attribute Details
#connector_arn ⇒ String
The Amazon Resource Name (ARN) of the connector.
1794 1795 1796 1797 1798 1799 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1794 class RestartConnectorResponse < Struct.new( :connector_arn, :connector_operation_arn) SENSITIVE = [] include Aws::Structure end |
#connector_operation_arn ⇒ String
The Amazon Resource Name (ARN) of the connector operation created to perform the restart.
1794 1795 1796 1797 1798 1799 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 1794 class RestartConnectorResponse < Struct.new( :connector_arn, :connector_operation_arn) SENSITIVE = [] include Aws::Structure end |