Class: Aws::KafkaConnect::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::KafkaConnect::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-kafkaconnect/client.rb,
sig/client.rbs
Overview
An API client for KafkaConnect. To construct a client, you need to configure a :region and :credentials.
client = Aws::KafkaConnect::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateConnectorResponseSuccess, _CreateCustomPluginResponseSuccess, _CreateWorkerConfigurationResponseSuccess, _DeleteConnectorResponseSuccess, _DeleteCustomPluginResponseSuccess, _DeleteWorkerConfigurationResponseSuccess, _DescribeConnectorOperationResponseSuccess, _DescribeConnectorResponseSuccess, _DescribeCustomPluginResponseSuccess, _DescribeWorkerConfigurationResponseSuccess, _ListConnectorOperationsResponseSuccess, _ListConnectorsResponseSuccess, _ListCustomPluginsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListWorkerConfigurationsResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateConnectorResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates a connector using the specified properties.
-
#create_custom_plugin(params = {}) ⇒ Types::CreateCustomPluginResponse
Creates a custom plugin using the specified properties.
-
#create_worker_configuration(params = {}) ⇒ Types::CreateWorkerConfigurationResponse
Creates a worker configuration using the specified properties.
-
#delete_connector(params = {}) ⇒ Types::DeleteConnectorResponse
Deletes the specified connector.
-
#delete_custom_plugin(params = {}) ⇒ Types::DeleteCustomPluginResponse
Deletes a custom plugin.
-
#delete_worker_configuration(params = {}) ⇒ Types::DeleteWorkerConfigurationResponse
Deletes the specified worker configuration.
-
#describe_connector(params = {}) ⇒ Types::DescribeConnectorResponse
Returns summary information about the connector.
-
#describe_connector_operation(params = {}) ⇒ Types::DescribeConnectorOperationResponse
Returns information about the specified connector's operations.
-
#describe_custom_plugin(params = {}) ⇒ Types::DescribeCustomPluginResponse
A summary description of the custom plugin.
-
#describe_worker_configuration(params = {}) ⇒ Types::DescribeWorkerConfigurationResponse
Returns information about a worker configuration.
-
#list_connector_operations(params = {}) ⇒ Types::ListConnectorOperationsResponse
Lists information about a connector's operation(s).
-
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Returns a list of all the connectors in this account and Region.
-
#list_custom_plugins(params = {}) ⇒ Types::ListCustomPluginsResponse
Returns a list of all of the custom plugins in this account and Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags attached to the specified resource.
-
#list_worker_configurations(params = {}) ⇒ Types::ListWorkerConfigurationsResponse
Returns a list of all of the worker configurations in this account and Region.
-
#tag_resource(params = {}) ⇒ Struct
Attaches tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_connector(params = {}) ⇒ Types::UpdateConnectorResponse
Updates the specified connector.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1510 1511 1512 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1510 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1513 1514 1515 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1513 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1483 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::KafkaConnect') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-kafkaconnect' context[:gem_version] = '1.60.0' Seahorse::Client::Request.new(handlers, context) end |
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates a connector using the specified properties.
88 |
# File 'sig/client.rbs', line 88
def create_connector: (
|
#create_custom_plugin(params = {}) ⇒ Types::CreateCustomPluginResponse
Creates a custom plugin using the specified properties.
169 |
# File 'sig/client.rbs', line 169
def create_custom_plugin: (
|
#create_worker_configuration(params = {}) ⇒ Types::CreateWorkerConfigurationResponse
Creates a worker configuration using the specified properties.
193 |
# File 'sig/client.rbs', line 193
def create_worker_configuration: (
|
#delete_connector(params = {}) ⇒ Types::DeleteConnectorResponse
Deletes the specified connector.
207 |
# File 'sig/client.rbs', line 207
def delete_connector: (
|
#delete_custom_plugin(params = {}) ⇒ Types::DeleteCustomPluginResponse
Deletes a custom plugin.
219 |
# File 'sig/client.rbs', line 219
def delete_custom_plugin: (
|
#delete_worker_configuration(params = {}) ⇒ Types::DeleteWorkerConfigurationResponse
Deletes the specified worker configuration.
230 |
# File 'sig/client.rbs', line 230
def delete_worker_configuration: (
|
#describe_connector(params = {}) ⇒ Types::DescribeConnectorResponse
Returns summary information about the connector.
257 |
# File 'sig/client.rbs', line 257
def describe_connector: (
|
#describe_connector_operation(params = {}) ⇒ Types::DescribeConnectorOperationResponse
Returns information about the specified connector's operations.
278 |
# File 'sig/client.rbs', line 278
def describe_connector_operation: (
|
#describe_custom_plugin(params = {}) ⇒ Types::DescribeCustomPluginResponse
A summary description of the custom plugin.
294 |
# File 'sig/client.rbs', line 294
def describe_custom_plugin: (
|
#describe_worker_configuration(params = {}) ⇒ Types::DescribeWorkerConfigurationResponse
Returns information about a worker configuration.
309 |
# File 'sig/client.rbs', line 309
def describe_worker_configuration: (
|
#list_connector_operations(params = {}) ⇒ Types::ListConnectorOperationsResponse
Lists information about a connector's operation(s).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
320 |
# File 'sig/client.rbs', line 320
def list_connector_operations: (
|
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Returns a list of all the connectors in this account and Region. The list is limited to connectors whose name starts with the specified prefix. The response also includes a description of each of the listed connectors.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
333 |
# File 'sig/client.rbs', line 333
def list_connectors: (
|
#list_custom_plugins(params = {}) ⇒ Types::ListCustomPluginsResponse
Returns a list of all of the custom plugins in this account and Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
346 |
# File 'sig/client.rbs', line 346
def list_custom_plugins: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags attached to the specified resource.
358 |
# File 'sig/client.rbs', line 358
def list_tags_for_resource: (
|
#list_worker_configurations(params = {}) ⇒ Types::ListWorkerConfigurationsResponse
Returns a list of all of the worker configurations in this account and Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
369 |
# File 'sig/client.rbs', line 369
def list_worker_configurations: (
|
#tag_resource(params = {}) ⇒ Struct
Attaches tags to the specified resource.
380 |
# File 'sig/client.rbs', line 380
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
390 |
# File 'sig/client.rbs', line 390
def untag_resource: (
|
#update_connector(params = {}) ⇒ Types::UpdateConnectorResponse
Updates the specified connector. For request body, specify only one
parameter: either capacity or connectorConfiguration.
403 |
# File 'sig/client.rbs', line 403
def update_connector: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1503 1504 1505 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1503 def waiter_names [] end |