Class: Aws::KafkaConnect::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::KafkaConnect::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-kafkaconnect/client.rb
Overview
An API client for KafkaConnect. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::KafkaConnect::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates a connector using the specified properties.
-
#create_custom_plugin(params = {}) ⇒ Types::CreateCustomPluginResponse
Creates a custom plugin using the specified properties.
-
#create_worker_configuration(params = {}) ⇒ Types::CreateWorkerConfigurationResponse
Creates a worker configuration using the specified properties.
-
#delete_connector(params = {}) ⇒ Types::DeleteConnectorResponse
Deletes the specified connector.
-
#delete_custom_plugin(params = {}) ⇒ Types::DeleteCustomPluginResponse
Deletes a custom plugin.
-
#delete_worker_configuration(params = {}) ⇒ Types::DeleteWorkerConfigurationResponse
Deletes the specified worker configuration.
-
#describe_connector(params = {}) ⇒ Types::DescribeConnectorResponse
Returns summary information about the connector.
-
#describe_connector_operation(params = {}) ⇒ Types::DescribeConnectorOperationResponse
Returns information about the specified connector’s operations.
-
#describe_custom_plugin(params = {}) ⇒ Types::DescribeCustomPluginResponse
A summary description of the custom plugin.
-
#describe_worker_configuration(params = {}) ⇒ Types::DescribeWorkerConfigurationResponse
Returns information about a worker configuration.
-
#list_connector_operations(params = {}) ⇒ Types::ListConnectorOperationsResponse
Lists information about a connector’s operation(s).
-
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Returns a list of all the connectors in this account and Region.
-
#list_custom_plugins(params = {}) ⇒ Types::ListCustomPluginsResponse
Returns a list of all of the custom plugins in this account and Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags attached to the specified resource.
-
#list_worker_configurations(params = {}) ⇒ Types::ListWorkerConfigurationsResponse
Returns a list of all of the worker configurations in this account and Region.
-
#tag_resource(params = {}) ⇒ Struct
Attaches tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_connector(params = {}) ⇒ Types::UpdateConnectorResponse
Updates the specified connector.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1510 1511 1512 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1510 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1513 1514 1515 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1513 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1483 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::KafkaConnect') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-kafkaconnect' context[:gem_version] = '1.58.0' Seahorse::Client::Request.new(handlers, context) end |
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates a connector using the specified properties.
630 631 632 633 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 630 def create_connector(params = {}, = {}) req = build_request(:create_connector, params) req.send_request() end |
#create_custom_plugin(params = {}) ⇒ Types::CreateCustomPluginResponse
Creates a custom plugin using the specified properties.
688 689 690 691 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 688 def create_custom_plugin(params = {}, = {}) req = build_request(:create_custom_plugin, params) req.send_request() end |
#create_worker_configuration(params = {}) ⇒ Types::CreateWorkerConfigurationResponse
Creates a worker configuration using the specified properties.
740 741 742 743 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 740 def create_worker_configuration(params = {}, = {}) req = build_request(:create_worker_configuration, params) req.send_request() end |
#delete_connector(params = {}) ⇒ Types::DeleteConnectorResponse
Deletes the specified connector.
775 776 777 778 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 775 def delete_connector(params = {}, = {}) req = build_request(:delete_connector, params) req.send_request() end |
#delete_custom_plugin(params = {}) ⇒ Types::DeleteCustomPluginResponse
Deletes a custom plugin.
806 807 808 809 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 806 def delete_custom_plugin(params = {}, = {}) req = build_request(:delete_custom_plugin, params) req.send_request() end |
#delete_worker_configuration(params = {}) ⇒ Types::DeleteWorkerConfigurationResponse
Deletes the specified worker configuration.
837 838 839 840 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 837 def delete_worker_configuration(params = {}, = {}) req = build_request(:delete_worker_configuration, params) req.send_request() end |
#describe_connector(params = {}) ⇒ Types::DescribeConnectorResponse
Returns summary information about the connector.
922 923 924 925 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 922 def describe_connector(params = {}, = {}) req = build_request(:describe_connector, params) req.send_request() end |
#describe_connector_operation(params = {}) ⇒ Types::DescribeConnectorOperationResponse
Returns information about the specified connector’s operations.
991 992 993 994 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 991 def describe_connector_operation(params = {}, = {}) req = build_request(:describe_connector_operation, params) req.send_request() end |
#describe_custom_plugin(params = {}) ⇒ Types::DescribeCustomPluginResponse
A summary description of the custom plugin.
1040 1041 1042 1043 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1040 def describe_custom_plugin(params = {}, = {}) req = build_request(:describe_custom_plugin, params) req.send_request() end |
#describe_worker_configuration(params = {}) ⇒ Types::DescribeWorkerConfigurationResponse
Returns information about a worker configuration.
1082 1083 1084 1085 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1082 def describe_worker_configuration(params = {}, = {}) req = build_request(:describe_worker_configuration, params) req.send_request() end |
#list_connector_operations(params = {}) ⇒ Types::ListConnectorOperationsResponse
Lists information about a connector’s operation(s).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1130 1131 1132 1133 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1130 def list_connector_operations(params = {}, = {}) req = build_request(:list_connector_operations, params) req.send_request() end |
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Returns a list of all the connectors in this account and Region. The list is limited to connectors whose name starts with the specified prefix. The response also includes a description of each of the listed connectors.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1212 1213 1214 1215 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1212 def list_connectors(params = {}, = {}) req = build_request(:list_connectors, params) req.send_request() end |
#list_custom_plugins(params = {}) ⇒ Types::ListCustomPluginsResponse
Returns a list of all of the custom plugins in this account and Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1269 1270 1271 1272 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1269 def list_custom_plugins(params = {}, = {}) req = build_request(:list_custom_plugins, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags attached to the specified resource.
1299 1300 1301 1302 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1299 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_worker_configurations(params = {}) ⇒ Types::ListWorkerConfigurationsResponse
Returns a list of all of the worker configurations in this account and Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1352 1353 1354 1355 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1352 def list_worker_configurations(params = {}, = {}) req = build_request(:list_worker_configurations, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Attaches tags to the specified resource.
1381 1382 1383 1384 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1381 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
1408 1409 1410 1411 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1408 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_connector(params = {}) ⇒ Types::UpdateConnectorResponse
Updates the specified connector. For request body, specify only one parameter: either ‘capacity` or `connectorConfiguration`.
1474 1475 1476 1477 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1474 def update_connector(params = {}, = {}) req = build_request(:update_connector, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1503 1504 1505 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1503 def waiter_names [] end |