Class: Aws::KafkaConnect::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::KafkaConnect::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-kafkaconnect/client.rb
Overview
An API client for KafkaConnect. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::KafkaConnect::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates a connector using the specified properties.
-
#create_custom_plugin(params = {}) ⇒ Types::CreateCustomPluginResponse
Creates a custom plugin using the specified properties.
-
#create_worker_configuration(params = {}) ⇒ Types::CreateWorkerConfigurationResponse
Creates a worker configuration using the specified properties.
-
#delete_connector(params = {}) ⇒ Types::DeleteConnectorResponse
Deletes the specified connector.
-
#delete_custom_plugin(params = {}) ⇒ Types::DeleteCustomPluginResponse
Deletes a custom plugin.
-
#delete_worker_configuration(params = {}) ⇒ Types::DeleteWorkerConfigurationResponse
Deletes the specified worker configuration.
-
#describe_connector(params = {}) ⇒ Types::DescribeConnectorResponse
Returns summary information about the connector.
-
#describe_connector_operation(params = {}) ⇒ Types::DescribeConnectorOperationResponse
Returns information about the specified connector’s operations.
-
#describe_custom_plugin(params = {}) ⇒ Types::DescribeCustomPluginResponse
A summary description of the custom plugin.
-
#describe_worker_configuration(params = {}) ⇒ Types::DescribeWorkerConfigurationResponse
Returns information about a worker configuration.
-
#list_connector_operations(params = {}) ⇒ Types::ListConnectorOperationsResponse
Lists information about a connector’s operation(s).
-
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Returns a list of all the connectors in this account and Region.
-
#list_custom_plugins(params = {}) ⇒ Types::ListCustomPluginsResponse
Returns a list of all of the custom plugins in this account and Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags attached to the specified resource.
-
#list_worker_configurations(params = {}) ⇒ Types::ListWorkerConfigurationsResponse
Returns a list of all of the worker configurations in this account and Region.
-
#tag_resource(params = {}) ⇒ Struct
Attaches tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_connector(params = {}) ⇒ Types::UpdateConnectorResponse
Updates the specified connector.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1512 1513 1514 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1512 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1515 1516 1517 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1515 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1485 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::KafkaConnect') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-kafkaconnect' context[:gem_version] = '1.54.0' Seahorse::Client::Request.new(handlers, context) end |
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates a connector using the specified properties.
632 633 634 635 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 632 def create_connector(params = {}, = {}) req = build_request(:create_connector, params) req.send_request() end |
#create_custom_plugin(params = {}) ⇒ Types::CreateCustomPluginResponse
Creates a custom plugin using the specified properties.
690 691 692 693 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 690 def create_custom_plugin(params = {}, = {}) req = build_request(:create_custom_plugin, params) req.send_request() end |
#create_worker_configuration(params = {}) ⇒ Types::CreateWorkerConfigurationResponse
Creates a worker configuration using the specified properties.
742 743 744 745 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 742 def create_worker_configuration(params = {}, = {}) req = build_request(:create_worker_configuration, params) req.send_request() end |
#delete_connector(params = {}) ⇒ Types::DeleteConnectorResponse
Deletes the specified connector.
777 778 779 780 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 777 def delete_connector(params = {}, = {}) req = build_request(:delete_connector, params) req.send_request() end |
#delete_custom_plugin(params = {}) ⇒ Types::DeleteCustomPluginResponse
Deletes a custom plugin.
808 809 810 811 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 808 def delete_custom_plugin(params = {}, = {}) req = build_request(:delete_custom_plugin, params) req.send_request() end |
#delete_worker_configuration(params = {}) ⇒ Types::DeleteWorkerConfigurationResponse
Deletes the specified worker configuration.
839 840 841 842 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 839 def delete_worker_configuration(params = {}, = {}) req = build_request(:delete_worker_configuration, params) req.send_request() end |
#describe_connector(params = {}) ⇒ Types::DescribeConnectorResponse
Returns summary information about the connector.
924 925 926 927 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 924 def describe_connector(params = {}, = {}) req = build_request(:describe_connector, params) req.send_request() end |
#describe_connector_operation(params = {}) ⇒ Types::DescribeConnectorOperationResponse
Returns information about the specified connector’s operations.
993 994 995 996 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 993 def describe_connector_operation(params = {}, = {}) req = build_request(:describe_connector_operation, params) req.send_request() end |
#describe_custom_plugin(params = {}) ⇒ Types::DescribeCustomPluginResponse
A summary description of the custom plugin.
1042 1043 1044 1045 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1042 def describe_custom_plugin(params = {}, = {}) req = build_request(:describe_custom_plugin, params) req.send_request() end |
#describe_worker_configuration(params = {}) ⇒ Types::DescribeWorkerConfigurationResponse
Returns information about a worker configuration.
1084 1085 1086 1087 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1084 def describe_worker_configuration(params = {}, = {}) req = build_request(:describe_worker_configuration, params) req.send_request() end |
#list_connector_operations(params = {}) ⇒ Types::ListConnectorOperationsResponse
Lists information about a connector’s operation(s).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1132 1133 1134 1135 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1132 def list_connector_operations(params = {}, = {}) req = build_request(:list_connector_operations, params) req.send_request() end |
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Returns a list of all the connectors in this account and Region. The list is limited to connectors whose name starts with the specified prefix. The response also includes a description of each of the listed connectors.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1214 1215 1216 1217 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1214 def list_connectors(params = {}, = {}) req = build_request(:list_connectors, params) req.send_request() end |
#list_custom_plugins(params = {}) ⇒ Types::ListCustomPluginsResponse
Returns a list of all of the custom plugins in this account and Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1271 1272 1273 1274 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1271 def list_custom_plugins(params = {}, = {}) req = build_request(:list_custom_plugins, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all the tags attached to the specified resource.
1301 1302 1303 1304 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1301 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_worker_configurations(params = {}) ⇒ Types::ListWorkerConfigurationsResponse
Returns a list of all of the worker configurations in this account and Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1354 1355 1356 1357 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1354 def list_worker_configurations(params = {}, = {}) req = build_request(:list_worker_configurations, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Attaches tags to the specified resource.
1383 1384 1385 1386 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1383 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
1410 1411 1412 1413 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1410 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_connector(params = {}) ⇒ Types::UpdateConnectorResponse
Updates the specified connector. For request body, specify only one parameter: either ‘capacity` or `connectorConfiguration`.
1476 1477 1478 1479 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1476 def update_connector(params = {}, = {}) req = build_request(:update_connector, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1505 1506 1507 |
# File 'lib/aws-sdk-kafkaconnect/client.rb', line 1505 def waiter_names [] end |