Class: Aws::KafkaConnect::Types::WorkerLogDeliveryDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::KafkaConnect::Types::WorkerLogDeliveryDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kafkaconnect/types.rb
Overview
Workers can send worker logs to different destination types. This configuration specifies the details of these destinations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_watch_logs ⇒ Types::CloudWatchLogsLogDeliveryDescription
Details about delivering logs to Amazon CloudWatch Logs.
-
#firehose ⇒ Types::FirehoseLogDeliveryDescription
Details about delivering logs to Amazon Kinesis Data Firehose.
-
#s3 ⇒ Types::S3LogDeliveryDescription
Details about delivering logs to Amazon S3.
Instance Attribute Details
#cloud_watch_logs ⇒ Types::CloudWatchLogsLogDeliveryDescription
Details about delivering logs to Amazon CloudWatch Logs.
2315 2316 2317 2318 2319 2320 2321 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 2315 class WorkerLogDeliveryDescription < Struct.new( :cloud_watch_logs, :firehose, :s3) SENSITIVE = [] include Aws::Structure end |
#firehose ⇒ Types::FirehoseLogDeliveryDescription
Details about delivering logs to Amazon Kinesis Data Firehose.
2315 2316 2317 2318 2319 2320 2321 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 2315 class WorkerLogDeliveryDescription < Struct.new( :cloud_watch_logs, :firehose, :s3) SENSITIVE = [] include Aws::Structure end |
#s3 ⇒ Types::S3LogDeliveryDescription
Details about delivering logs to Amazon S3.
2315 2316 2317 2318 2319 2320 2321 |
# File 'lib/aws-sdk-kafkaconnect/types.rb', line 2315 class WorkerLogDeliveryDescription < Struct.new( :cloud_watch_logs, :firehose, :s3) SENSITIVE = [] include Aws::Structure end |